@@ -71,6 +71,12 @@ class ASTUnparse(ast.NodeVisitor):
         self.f = f
         self.level = 0
 
+    def stmt_end(self, node):
+        self.nl()
+
+    def nl(self):
+        self.f.write("\n")
+
     def indent(self):
         for i in range(self.level):
             self.f.write("    ")
@@ -101,57 +107,73 @@ class ASTUnparse(ast.NodeVisitor):
         self.visit(node.target)
         self.f.write(" in ")
         self.visit(node.iter)
-        self.f.write(":\n")
+        self.f.write(":")
+        self.stmt_end(node)
         self.visit_suite(node.body)
         if node.orelse:
-            self.with_indent("else:\n")
+            self.with_indent("else:")
+            self.nl()
             self.visit_suite(node.orelse)
 
     def visit_While(self, node):
         self.with_indent("while ")
         self.visit(node.test)
-        self.f.write(":\n")
+        self.f.write(":")
+        self.stmt_end(node)
         self.visit_suite(node.body)
         if node.orelse:
-            self.with_indent("else:\n")
+            self.with_indent("else:")
+            self.nl()
             self.visit_suite(node.orelse)
 
     def visit_If(self, node):
         self.with_indent("if ")
         while True:
             self.visit(node.test)
-            self.f.write(":\n")
+            self.f.write(":")
+            self.stmt_end(node)
             self.visit_suite(node.body)
             if node.orelse:
                 if len(node.orelse) == 1 and isinstance(node.orelse[0], ast.If):
                     node = node.orelse[0]
                     self.with_indent("elif ")
                     continue
-                self.with_indent("else:\n")
+                self.with_indent("else:")
+                self.nl()
                 self.visit_suite(node.orelse)
             break
 
+    def visit_AugAssign(self, node):
+        self.indent()
+        self.visit(node.target)
+        self.f.write(" %s= " % self.__class__.binop_map[type(node.op)])
+        self.visit(node.value)
+        self.stmt_end(node)
+
     def visit_Assign(self, node):
         self.indent()
         for n in node.targets:
             self.visit(n)
             self.f.write(" = ")
         self.visit(node.value)
-        self.f.write("\n")
+        self.stmt_end(node)
 
     def visit_Expr(self, node):
         self.indent()
         self.visit(node.value)
-        self.f.write("\n")
+        self.stmt_end(node)
 
     def visit_Continue(self, node):
-        self.with_indent("continue\n")
+        self.with_indent("continue")
+        self.stmt_end(node)
 
     def visit_Break(self, node):
-        self.with_indent("break\n")
+        self.with_indent("break")
+        self.stmt_end(node)
 
     def visit_Pass(self, node):
-        self.with_indent("pass\n")
+        self.with_indent("pass")
+        self.stmt_end(node)
 
     def _visit_expr(self, parent, child, paren_on_equal=False):
         # Render a node which is a part of expression, wrapping in parens
@@ -174,8 +196,6 @@ class ASTUnparse(ast.NodeVisitor):
             nonlocal need_comma
             if need_comma:
                 self.f.write(", ")
-            else:
-                self.f.write(" ")
             need_comma = True
         for a in args.args:
             comma()
@@ -183,7 +203,10 @@ class ASTUnparse(ast.NodeVisitor):
 
     def visit_Lambda(self, node):
         self.f.write("lambda")
-        self._visit_arguments(node.args)
+        args = node.args
+        if args.args:
+            self.f.write(" ")
+        self._visit_arguments(args)
         self.f.write(": ")
         self.visit(node.body)
 
@@ -247,6 +270,10 @@ class ASTUnparse(ast.NodeVisitor):
             self.f.write(" ")
         self._visit_expr(node, node.operand)
 
+    def visit_Await(self, node):
+        self.f.write("await ")
+        self._visit_expr(node, node.value)
+
     def visit_Subscript(self, node):
         self.visit(node.value)
         self.f.write("[")
